Description: Illinois Courts Information Site. Contains Supreme, Appellate and Circuit Court information, including judges, and the opinions of the Supreme and Appellate Courts.

Loading

Local Court Information:
The Illinois Courts now offer two ways to be notified of news and court-related information. Illinois Courts Twitter Account E-mail List Notification
# Recent Supreme Court Opinions
Search Opinions: Loading The following opinions were uploaded to the Illinois Courts Web Site on the indicated Posted date. This listing will be maintained for 90 days at which time the oldest opinions will be moved to an Archive table. All Opinions are in PDF format. To view a PDF file you will need Adobe Acrobat Reader which is available free of charge. NRel beside case number indicates slip opinion not yet released for publication. Official Reports indicates the final, released version of the opinion. For additional information, please read A Caution on Court Opinions. Sorting Opinions: Opinions may be sorted by 'Posting Date', 'Filing Date', 'Docket #', 'Public Domain Citation #", or 'Case Name.' Click on the column name/header, the opinions will sort in descending/ascending order. ### For opinions older than 90 days, please go to our Opinions Archive page.
Posting Date | Filing Date | Docket # | Public Domain Citation # | Case Name (PDF) | Case Summary
--- | --- | --- | --- | --- | ---
03/24/16 | 03/24/16 | 118181 NRel | 2016 IL 118181 | People v. Timmsen |
03/24/16 | 03/24/16 | 118422 NRel | 2016 IL 118422 | State of Illinois v. American Federation of State, County & Municipal Employees, Council 31 |
03/24/16 | 03/24/16 | 118674 NRel | 2016 IL 118674 | People v. Bradford |
03/24/16 | 03/24/16 | 118845 NRel | 2016 IL 118845 | People v. Clark |
03/24/16 | 03/24/16 | 118973 NRel | 2016 IL 118973 | People v. Burns |
03/24/16 | 03/24/16 | 119181 NRel | 2016 IL 119181 | Vaughn v. City of Carbondale |
03/24/16 | 03/24/16 | 119618, 119620, 119638, 119639, 119644 cons. | 2016 IL 119618 | Jones v. Municipal Employees' Annuity & Benefit Fund |
03/03/16 | 01/22/16 | 118693 Official Reports | 2016 IL 118693 | People v. Salem |
03/03/16 | 01/22/16 | 115769 Official Reports | 2016 IL 115769 | People v. Cummings |
03/03/16 | 01/22/16 | 117911 Official Reports | 2016 IL 117911 | People v. Chambers |
03/03/16 | 01/22/16 | 117952 Official Reports | 2016 IL 117952 | Coleman v. East Joliet Fire Protection District |
03/03/16 | 01/22/16 | 118123 Official Reports | 2016 IL 118123 | People v. Sanders |
03/03/16 | 01/22/16 | 118217 Official Reports | 2016 IL 118217 | Klaine v. Southern Illinois Hospital Services |
03/03/16 | 01/22/16 | 118375 Official Reports | 2016 IL 118375 | People v. Williams |
03/03/16 | 01/22/16 | 118496 Official Reports | 2016 IL 118496 | People v. Lerma |
02/26/16 | 02/26/16 | 118661 NRel | 2016 IL 118661 | People v. Boston |
02/19/16 | 02/19/16 | 118023 NRel | 2016 IL 118023 | People v. Ligon |
02/04/16 | 02/04/16 | 118562 NRel | 2016 IL 118562 | Petrovic v. The Department of Employment Security |
01/28/16 | 11/04/15 | 118139 NRel | 2015 IL 118139 | Henderson Square Condominium Association v. LAB Townhomes, LLC - Modified on Denial of Rehearing 1/28/16 |
01/25/16 | 12/17/15 | 117242 Offical Reports | 2015 IL 117242 | People v. Hughes |
01/25/16 | 12/17/15 | 117387Offical Reports | 2015 IL 117387 | People v. Burns |
01/25/16 | 12/17/15 | 118043, 118072 cons. Offical Reports | 2015 IL 118043 | Board of Education of the City of Chicago v. Illinois Educational Labor Relations Board |
01/25/16 | 12/17/15 | 119178 Offical Reports | 2015 IL 119178 | In re Michael D. |
01/22/16 | 01/22/16 | 117846 NRel | 2016 IL 117846 | People v. Tolbert |
01/22/16 | 01/22/16 | 118667 NRel | 2016 IL 118667 | People v. Thompson |
01/08/16 | 12/03/15 | 117709 Official Reports | 2015 IL 117709 | People v. Carter |
01/08/16 | 12/03/15 | 117789 Official Reports | 2015 IL 117789 | People v. Schweihs |
01/08/16 | 12/03/15 | 118151 Official Reports | 2015 IL 118151 | People v. Thompson |
01/08/16 | 12/03/15 | 118218 Official Reports | 2015 IL 118218 | People v. Espinoza |
01/08/16 | 12/03/15 | 118372 Official Reports | 2015 IL 118372 | 1010 Lake Shore Association v. Deutsche Bank National Trust Company |
01/08/16 | 12/03/15 | 118975 Official Reports | 2015 IL 118975 | DG Enterprises v. Cornelius |